EXPORTS
	__8RCloggerPv @ 1 NONAME R3UNUSED ; RClogger::RClogger(void *)
	Close__19RCloggerLogConsumer @ 2 NONAME R3UNUSED ; RCloggerLogConsumer::Close(void)
	Close__8RClogger @ 3 NONAME R3UNUSED ; RClogger::Close(void)
	Connect__19RCloggerLogConsumer @ 4 NONAME R3UNUSED ; RCloggerLogConsumer::Connect(void)
	Connect__8RClogger @ 5 NONAME R3UNUSED ; RClogger::Connect(void)
	Connect__8RCloggerRC7TDesC16 @ 6 NONAME R3UNUSED ; RClogger::Connect(TDesC16 const &)
	GetGlobalOptions__8RClogger @ 7 NONAME R3UNUSED ; RClogger::GetGlobalOptions(void)
	GetNextLog__19RCloggerLogConsumerR14TRequestStatusR6TPtrC8 @ 8 NONAME R3UNUSED ; RCloggerLogConsumer::GetNextLog(TRequestStatus &, TPtrC8 &)
	GetRamBufferSize__8RCloggerPi @ 9 NONAME R3UNUSED ; RClogger::GetRamBufferSize(int *)
	GetRotateBehaviour__8RCloggerPi @ 10 NONAME R3UNUSED ; RClogger::GetRotateBehaviour(int *)
	GetTagStatesL__8RCloggerRP12CDesC16ArrayR5RBuf8 @ 11 NONAME R3UNUSED ; RClogger::GetTagStatesL(CDesC16Array *&, RBuf8 &)
	HexDump__8RCloggerRC6TDesC8T1 @ 12 NONAME R3UNUSED ; RClogger::HexDump(TDesC8 const &, TDesC8 const &)
	HexDump__8RCloggerUlRC6TDesC8T2 @ 13 NONAME ; RClogger::HexDump(unsigned long, TDesC8 const &, TDesC8 const &)
	IsEnabled__8RCloggerRC7TDesC16 @ 14 NONAME R3UNUSED ; RClogger::IsEnabled(TDesC16 const &)
	LogList__8RCloggerGt11TRefByValue1ZC6TDesC8PPSc @ 15 NONAME R3UNUSED ; RClogger::LogList(TRefByValue<TDesC8 const>, signed char **)
	LogList__8RCloggerGt11TRefByValue1ZC7TDesC16PPSc @ 16 NONAME R3UNUSED ; RClogger::LogList(TRefByValue<TDesC16 const>, signed char **)
	LogList__8RCloggerPCcPPSc @ 17 NONAME R3UNUSED ; RClogger::LogList(char const *, signed char **)
	LogList__8RCloggerUlGt11TRefByValue1ZC6TDesC8PPSc @ 18 NONAME ; RClogger::LogList(unsigned long, TRefByValue<TDesC8 const>, signed char **)
	LogList__8RCloggerUlGt11TRefByValue1ZC7TDesC16PPSc @ 19 NONAME ; RClogger::LogList(unsigned long, TRefByValue<TDesC16 const>, signed char **)
	LogList__8RCloggerUlPCcPPSc @ 20 NONAME ; RClogger::LogList(unsigned long, char const *, signed char **)
	Log__8RCloggerGt11TRefByValue1ZC6TDesC8e @ 21 NONAME ; RClogger::Log(TRefByValue<TDesC8 const>,...)
	Log__8RCloggerGt11TRefByValue1ZC7TDesC16e @ 22 NONAME ; RClogger::Log(TRefByValue<TDesC16 const>,...)
	Log__8RCloggerPCce @ 23 NONAME ; RClogger::Log(char const *,...)
	Log__8RCloggerUlGt11TRefByValue1ZC6TDesC8e @ 24 NONAME ; RClogger::Log(unsigned long, TRefByValue<TDesC8 const>,...)
	Log__8RCloggerUlGt11TRefByValue1ZC7TDesC16e @ 25 NONAME ; RClogger::Log(unsigned long, TRefByValue<TDesC16 const>,...)
	Log__8RCloggerUlPCce @ 26 NONAME ; RClogger::Log(unsigned long, char const *,...)
	PersistSettings__8RClogger @ 27 NONAME R3UNUSED ; RClogger::PersistSettings(void)
	Reserved__8RCloggeriRPvPv @ 28 NONAME ; RClogger::Reserved(int, void *&, void *)
	ResetSettings__8RClogger @ 29 NONAME R3UNUSED ; RClogger::ResetSettings(void)
	Rotate__8RClogger @ 30 NONAME R3UNUSED ; RClogger::Rotate(void)
	Rotate__8RCloggerR6TDes16 @ 31 NONAME R3UNUSED ; RClogger::Rotate(TDes16 &)
	SetEnabled__8RCloggerRC7TDesC16Ul @ 32 NONAME R3UNUSED ; RClogger::SetEnabled(TDesC16 const &, unsigned long)
	SetGlobalOptions__8RCloggerUi @ 33 NONAME R3UNUSED ; RClogger::SetGlobalOptions(unsigned int)
	SetLogBehaviour__8RCloggerUi @ 34 NONAME R3UNUSED ; RClogger::SetLogBehaviour(unsigned int)
	SetRamBufferSize__8RCloggerii @ 35 NONAME R3UNUSED ; RClogger::SetRamBufferSize(int, int)
	SetRotateBehaviour__8RCloggeriUi @ 36 NONAME R3UNUSED ; RClogger::SetRotateBehaviour(int, unsigned int)
	SetStaticLogBehaviour__8RCloggerUi @ 37 NONAME R3UNUSED ; RClogger::SetStaticLogBehaviour(unsigned int)
	SetTagStatesL__8RCloggerPC12CDesC16ArrayRC6TDesC8 @ 38 NONAME R3UNUSED ; RClogger::SetTagStatesL(CDesC16Array const *, TDesC8 const &)
	SlogList__8RCloggerGt11TRefByValue1ZC6TDesC8PPSc @ 39 NONAME R3UNUSED ; RClogger::SlogList(TRefByValue<TDesC8 const>, signed char **)
	SlogList__8RCloggerGt11TRefByValue1ZC7TDesC16PPSc @ 40 NONAME R3UNUSED ; RClogger::SlogList(TRefByValue<TDesC16 const>, signed char **)
	SlogList__8RCloggerPCcPPSc @ 41 NONAME R3UNUSED ; RClogger::SlogList(char const *, signed char **)
	SlogList__8RCloggerUlGt11TRefByValue1ZC6TDesC8PPSc @ 42 NONAME R3UNUSED ; RClogger::SlogList(unsigned long, TRefByValue<TDesC8 const>, signed char **)
	SlogList__8RCloggerUlGt11TRefByValue1ZC7TDesC16PPSc @ 43 NONAME R3UNUSED ; RClogger::SlogList(unsigned long, TRefByValue<TDesC16 const>, signed char **)
	SlogList__8RCloggerUlPCcPPSc @ 44 NONAME R3UNUSED ; RClogger::SlogList(unsigned long, char const *, signed char **)
	Slog__8RCloggerGt11TRefByValue1ZC6TDesC8e @ 45 NONAME ; RClogger::Slog(TRefByValue<TDesC8 const>,...)
	Slog__8RCloggerGt11TRefByValue1ZC7TDesC16e @ 46 NONAME ; RClogger::Slog(TRefByValue<TDesC16 const>,...)
	Slog__8RCloggerPCce @ 47 NONAME ; RClogger::Slog(char const *,...)
	Slog__8RCloggerUlGt11TRefByValue1ZC6TDesC8e @ 48 NONAME ; RClogger::Slog(unsigned long, TRefByValue<TDesC8 const>,...)
	Slog__8RCloggerUlGt11TRefByValue1ZC7TDesC16e @ 49 NONAME ; RClogger::Slog(unsigned long, TRefByValue<TDesC16 const>,...)
	Slog__8RCloggerUlPCce @ 50 NONAME ; RClogger::Slog(unsigned long, char const *,...)
	StaticClose__8RClogger @ 51 NONAME R3UNUSED ; RClogger::StaticClose(void)
	StaticConnect__8RClogger @ 52 NONAME R3UNUSED ; RClogger::StaticConnect(void)
	StaticConnect__8RCloggerRC7TDesC16 @ 53 NONAME R3UNUSED ; RClogger::StaticConnect(TDesC16 const &)
	StaticHexDump__8RCloggerRC6TDesC8T1 @ 54 NONAME R3UNUSED ; RClogger::StaticHexDump(TDesC8 const &, TDesC8 const &)
	StaticHexDump__8RCloggerUlRC6TDesC8T2 @ 55 NONAME R3UNUSED ; RClogger::StaticHexDump(unsigned long, TDesC8 const &, TDesC8 const &)
	StaticReserved__8RCloggeriRPvPv @ 56 NONAME R3UNUSED ; RClogger::StaticReserved(int, void *&, void *)
	__19RCloggerLogConsumer @ 57 NONAME R3UNUSED ; RCloggerLogConsumer::RCloggerLogConsumer(void)
	__8RClogger @ 58 NONAME R3UNUSED ; RClogger::RClogger(void)
	CancelGetNextLog__19RCloggerLogConsumer @ 59 NONAME R3UNUSED ; RCloggerLogConsumer::CancelGetNextLog(void)
	Clogger_Slog @ 60 NONAME ; (null)

